/*= Rohde&Schwarz SMR Microwave Generator Include File ======================*/

/*===========================================================================*/
/*  Please do not use global variables or arrays in the include file of      */
/*  instrument drivers that will be submitted for inclusion into the         */
/*  LabWindows Instrument Driver Library.                                    */
/*===========================================================================*/
     
#ifndef __RSSMR_HEADER
#define __RSSMR_HEADER

#include <vpptype.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*****************************************************************************/
/*= Instrument Driver Specific Error/Warning Codes ==========================*/
/*****************************************************************************/
#define VI_ERROR_INSTR_FILE_OPEN                (_VI_ERROR+0x3FFC0800L)
#define VI_ERROR_INSTR_FILE_WRITE               (_VI_ERROR+0x3FFC0801L)
#define VI_ERROR_INSTR_INTERPRETING_RESPONSE    (_VI_ERROR+0x3FFC0803L)
#define VI_ERROR_INSTR_PARAMETER9               (_VI_ERROR+0x3FFC0809L)
#define VI_ERROR_INSTR_PARAMETER10              (_VI_ERROR+0x3FFC080AL)
#define VI_ERROR_INSTR_PARAMETER11              (_VI_ERROR+0x3FFC080BL)
#define VI_ERROR_INSTR_PARAMETER12              (_VI_ERROR+0x3FFC080CL)
#define VI_ERROR_INSTR_PARAMETER13              (_VI_ERROR+0x3FFC080DL)
#define VI_ERROR_INSTR_PARAMETER14              (_VI_ERROR+0x3FFC080EL)
#define VI_ERROR_INSTR_PARAMETER15              (_VI_ERROR+0x3FFC080FL)

/*****************************************************************************/
/*= Define Instrument Specific Error/Warning Codes Here =====================*/
/*****************************************************************************/
#define VI_WARNING_INSTR_OFFSET                           (0x3FFC0900L)
#define VI_ERROR_INSTR_OFFSET                   (_VI_ERROR+0x3FFC0900L)

#define RSSMR_ERROR_INSTRUMENT_ERROR           (VI_ERROR_INSTR_OFFSET + 0xF0L)
#define RSSMR_ERROR_INVALID_CONFIGURATION      (VI_ERROR_INSTR_OFFSET + 0xF1L)
#define RSSMR_ERROR_INSTRUMENT_OPTION          (VI_ERROR_INSTR_OFFSET + 0xF2L)

/*****************************************************************************/
/*= GLOBAL USER-CALLABLE FUNCTION DECLARATIONS (Exportable Functions) =======*/
/*****************************************************************************/

ViStatus _VI_FUNC rssmr_init (ViRsrc resourceName, ViBoolean IDQuery,
                ViBoolean resetDevice, ViPSession instrSession);
ViStatus _VI_FUNC rssmr_exOutAmpl (ViSession instrSession, ViReal64 frequency,
                ViReal64 offset, ViReal64 level,
                ViInt32 modulationSource,
                ViReal64 modulationDepth,
                ViReal64 modulationFrequency);
ViStatus _VI_FUNC rssmr_configRFFreq (ViSession instrSession,
                ViReal64 frequency, ViReal64 offset,
                ViReal64 multiplier);
ViStatus _VI_FUNC rssmr_setCWFreq (ViSession instrSession, ViReal64 frequency);
ViStatus _VI_FUNC rssmr_setRFFreqOffset (ViSession instrSession,
                ViReal64 offset);
ViStatus _VI_FUNC rssmr_setRFFreqMultiplier (ViSession instrSession,
                ViReal64 multiplier);
ViStatus _VI_FUNC rssmr_setCWFreqReset (ViSession instrSession,
                ViInt32 resetState);
ViStatus _VI_FUNC rssmr_setRFFreqMode (ViSession instrSession,
                ViInt32 operatingMode);
ViStatus _VI_FUNC rssmr_configRFFreqSweep (ViSession instrSession,
                ViInt32 sweepMode,
                ViReal64 startFrequency,
                ViReal64 stopFrequency,
                ViReal64 increment, ViReal64 dwellTime);
ViStatus _VI_FUNC rssmr_setRFFreqSweepMode (ViSession instrSession,
                ViInt32 sweepMode);
ViStatus _VI_FUNC rssmr_setRFStartFreq (ViSession instrSession,
                ViReal64 frequency);
ViStatus _VI_FUNC rssmr_setRFStopFreq (ViSession instrSession,
                ViReal64 frequency);
ViStatus _VI_FUNC rssmr_setRFFreqIncrement (ViSession instrSession,
                ViReal64 increment);
ViStatus _VI_FUNC rssmr_setRFFreqSweepDwellTime (ViSession instrSession,
                ViReal64 time);
ViStatus _VI_FUNC rssmr_setSweepBlankTime (ViSession instrSession,
                ViInt32 time);
ViStatus _VI_FUNC rssmr_setRFFreqSweepSpacing (ViSession instrSession,
                ViInt32 spacing);
ViStatus _VI_FUNC rssmr_setRFFreqSweepStep (ViSession instrSession,
                ViInt32 mode, ViReal64 step);
ViStatus _VI_FUNC rssmr_setRFSweepFreqManual (ViSession instrSession,
                ViReal64 frequency);
ViStatus _VI_FUNC rssmr_setRFCenterFreq (ViSession instrSession,
                ViReal64 frequency);
ViStatus _VI_FUNC rssmr_setRFSpanFreq (ViSession instrSession,
                ViReal64 frequency);
ViStatus _VI_FUNC rssmr_configRFLevel (ViSession instrSession, ViReal64 level,
                ViReal64 offset, ViReal64 limit);
ViStatus _VI_FUNC rssmr_setRFLevel (ViSession instrSession, ViReal64 level);
ViStatus _VI_FUNC rssmr_setRFLevelOffset (ViSession instrSession,
                ViReal64 offset);
ViStatus _VI_FUNC rssmr_setRFLevelLimit (ViSession instrSession,
                ViReal64 limit);
ViStatus _VI_FUNC rssmr_setRFLevelReset (ViSession instrSession,
                ViInt32 resetState);
ViStatus _VI_FUNC rssmr_setFixedPowerMode (ViSession instrSession);
ViStatus _VI_FUNC rssmr_configRFLevelSweep (ViSession instrSession,
                ViInt32 sweepMode, ViReal64 startLevel,
                ViReal64 stopLevel, ViReal64 step,
                ViReal64 dwellTime);
ViStatus _VI_FUNC rssmr_setRFLevelSweepMode (ViSession instrSession,
                ViInt32 sweepMode);
ViStatus _VI_FUNC rssmr_setRFStartLevel (ViSession instrSession,
                ViReal64 level);
ViStatus _VI_FUNC rssmr_setRFStopFreqLevel (ViSession instrSession,
                ViReal64 level);
ViStatus _VI_FUNC rssmr_setRFLevelIncrement (ViSession instrSession,
                                             ViReal64 increment);
ViStatus _VI_FUNC rssmr_setRFLevelSweepStep (ViSession instrSession,
                ViReal64 step);
ViStatus _VI_FUNC rssmr_setRFLevelSweepDwellTime (ViSession instrSession,
                ViReal64 time);
ViStatus _VI_FUNC rssmr_setRFLevelSweepManual (ViSession instrSession,
                ViReal64 level);
ViStatus _VI_FUNC rssmr_setRFLevelSweepSpacing (ViSession instrSession,
                ViInt32 spacing);
ViStatus _VI_FUNC rssmr_setSweepPowerMode (ViSession instrSession);
ViStatus _VI_FUNC rssmr_setRfLevelUnit (ViSession instrSession,
                                        ViInt32 levelUnit);
ViStatus _VI_FUNC rssmr_ConfigureRFLevelCorr (ViSession instrSession,
                ViBoolean correctionState,
                ViString correctionListName,
                ViReal64 _VI_FAR frequencyPoints[],
                ViReal64 _VI_FAR powerPoints[],
                ViInt32 numberOfElements);
ViStatus _VI_FUNC rssmr_setRFLevelCorrState (ViSession instrSession,
                ViBoolean correctionState);
ViStatus _VI_FUNC rssmr_selCorrList (ViSession instrSession,
                ViString correctionListName);
ViStatus _VI_FUNC rssmr_deleteCorrList (ViSession instrSession,
                ViString correctionListName);
ViStatus _VI_FUNC rssmr_deleteAllCorrLists (ViSession instrSession);
ViStatus _VI_FUNC rssmr_getListOfCorrLists (ViSession instrSession,
                ViChar _VI_FAR listOfCorrectionLists[]);
ViStatus _VI_FUNC rssmr_setFreqToCorrList (ViSession instrSession,
                ViReal64 _VI_FAR frequency[],
                ViInt32 size);
ViStatus _VI_FUNC rssmr_setPowerToCorrList (ViSession instrSession,
                ViReal64 _VI_FAR power[], ViInt32 size);
ViStatus _VI_FUNC rssmr_getLevelCorrPoints (ViSession instrSession,
                ViPInt32 points);
ViStatus _VI_FUNC rssmr_getFreqCorrPoints (ViSession instrSession,
                                           ViPInt32 points);
ViStatus _VI_FUNC rssmr_getFreeCorrTables (ViSession instrSession,
                ViPInt32 freeSpace);
ViStatus _VI_FUNC rssmr_configRFOutput (ViSession instrSession,
                ViBoolean outputState,
                ViInt32 attenuationMode,
                ViReal64 attenuation);
ViStatus _VI_FUNC rssmr_setRFOutputState (ViSession instrSession,
                ViBoolean outputState);
ViStatus _VI_FUNC rssmr_setRFAttMode (ViSession instrSession,
                ViInt32 attenuationMode);
ViStatus _VI_FUNC rssmr_setRFAttenuation (ViSession instrSession,
                ViReal64 attenuation);
ViStatus _VI_FUNC rssmr_getRFOutputImpedance (ViSession instrSession,
                ViPReal64 impedance);
ViStatus _VI_FUNC rssmr_setRFOutPowOnState (ViSession instrSession,
                ViInt32 outputState);
ViStatus _VI_FUNC rssmr_configAMModulation (ViSession instrSession,
                ViInt32 modulationSource,
                ViReal64 modulationDepth,
                ViReal64 frequency);
ViStatus _VI_FUNC rssmr_configFMModulation (ViSession instrSession,
                ViInt32 modulationSource,
                ViReal64 deviation, ViReal64 frequency);
ViStatus _VI_FUNC rssmr_configPulseModulation (ViSession instrSession,
                ViInt32 signalSource,
                ViInt32 polarity);
ViStatus _VI_FUNC rssmr_configDigitalModulation (ViSession instrSession,
                ViInt32 modulationType,
                ViReal64 FSKDeviation,
                ViInt32 FSKPolarity,
                ViReal64 ASKDepth,
                ViInt32 ASKPolarity);
ViStatus _VI_FUNC rssmr_setAMState (ViSession instrSession,
                ViBoolean AMModState);
ViStatus _VI_FUNC rssmr_setAMDepth (ViSession instrSession, ViReal64 depth);
ViStatus _VI_FUNC rssmr_setAMFreq (ViSession instrSession, ViReal64 frequency);
ViStatus _VI_FUNC rssmr_setAMSource (ViSession instrSession,
                ViInt32 modulationSource);
ViStatus _VI_FUNC rssmr_setAMExtCoupling (ViSession instrSession,
                ViInt32 extInput, ViInt32 coupling);
ViStatus _VI_FUNC rssmr_setAMExtImp (ViSession instrSession, ViInt32 extInput,
                ViInt32 impedance);
ViStatus _VI_FUNC rssmr_setAMScanState (ViSession instrSession,
                ViBoolean modState);
ViStatus _VI_FUNC rssmr_setAMScanSens (ViSession instrSession,
                ViReal64 sensitivity);
ViStatus _VI_FUNC rssmr_setFMState (ViSession instrSession, ViBoolean modState);
ViStatus _VI_FUNC rssmr_setFMDeviation (ViSession instrSession,
                ViReal64 deviation);
ViStatus _VI_FUNC rssmr_setFMFreq (ViSession instrSession, ViReal64 frequency);
ViStatus _VI_FUNC rssmr_setFMSource (ViSession instrSession,
                ViInt32 modulationSource);
ViStatus _VI_FUNC rssmr_setFMExtCoup (ViSession instrSession, ViInt32 extInput,
                ViInt32 coupling);
ViStatus _VI_FUNC rssmr_setFMExtImp (ViSession instrSession, ViInt32 extInput,
                ViInt32 impedance);
ViStatus _VI_FUNC rssmr_setPMState (ViSession instrSession, ViBoolean modState);
ViStatus _VI_FUNC rssmr_setPMPolar (ViSession instrSession, ViInt32 polarity);
ViStatus _VI_FUNC rssmr_setPMSource (ViSession instrSession,
                ViInt32 modulationSource);
ViStatus _VI_FUNC rssmr_setPMExtImp (ViSession instrSession,
                ViReal64 impedance);
ViStatus _VI_FUNC rssmr_setDMState (ViSession instrSession, ViBoolean modState);
ViStatus _VI_FUNC rssmr_setDMType (ViSession instrSession,
                ViInt32 modulationType);
ViStatus _VI_FUNC rssmr_setFSKDeviation (ViSession instrSession,
                ViReal64 deviation);
ViStatus _VI_FUNC rssmr_setFSKPolar (ViSession instrSession, ViInt32 polarity);
ViStatus _VI_FUNC rssmr_setASKDepth (ViSession instrSession, ViReal64 depth);
ViStatus _VI_FUNC rssmr_setASKPolar (ViSession instrSession, ViInt32 polarity);
ViStatus _VI_FUNC rssmr_setDMExtImp (ViSession instrSession, ViInt32 impedance);
ViStatus _VI_FUNC rssmr_configureALC (ViSession instrSession,
                ViBoolean levelControl, ViInt32 source,
                ViReal64 reference);
ViStatus _VI_FUNC rssmr_setALCState (ViSession instrSession,
                ViBoolean ALCState);
ViStatus _VI_FUNC rssmr_setALCSource (ViSession instrSession, ViInt32 source);
ViStatus _VI_FUNC rssmr_setALCSlope (ViSession instrSession, ViInt32 slope);
ViStatus _VI_FUNC rssmr_setALCReference (ViSession instrSession,
                ViReal64 reference);
ViStatus _VI_FUNC rssmr_ALCSearch (ViSession instrSession,
                ViChar _VI_FAR searchResult[]);
ViStatus _VI_FUNC rssmr_configLFOutput (ViSession instrSession,
                ViBoolean LFOutputState,
                ViInt32 signalShape, ViReal64 frequency,
                ViReal64 voltage);
ViStatus _VI_FUNC rssmr_setLFOutputState (ViSession instrSession,
                ViBoolean LFOutputState);
ViStatus _VI_FUNC rssmr_setLFCWFreq (ViSession instrSession,
                ViReal64 frequency);
ViStatus _VI_FUNC rssmr_setLFVoltage (ViSession instrSession, ViReal64 voltage);
ViStatus _VI_FUNC rssmr_setLFFreqMode (ViSession instrSession,
                ViInt32 operatingMode);
ViStatus _VI_FUNC rssmr_setLFFunction (ViSession instrSession,
                ViInt32 signalShape);
ViStatus _VI_FUNC rssmr_configLFSweep (ViSession instrSession,
                ViInt32 sweepMode, ViReal64 startFrequency,
                ViReal64 stopFrequency, ViReal64 step,
                ViReal64 dwellTime);
ViStatus _VI_FUNC rssmr_setLFSweepMode (ViSession instrSession,
                ViInt32 sweepMode);
ViStatus _VI_FUNC rssmr_setLFStartFreq (ViSession instrSession,
                ViReal64 frequency);
ViStatus _VI_FUNC rssmr_setLFStopFreq (ViSession instrSession,
                ViReal64 frequency);
ViStatus _VI_FUNC rssmr_setLFFreqMan (ViSession instrSession,
                ViReal64 frequency);
ViStatus _VI_FUNC rssmr_setLFSweepSpac (ViSession instrSession,
                ViInt32 spacing);
ViStatus _VI_FUNC rssmr_setLFSweepStep (ViSession instrSession, ViInt32 mode,
                ViReal64 step);
ViStatus _VI_FUNC rssmr_setLFSweepBlankTime (ViSession instrSession,
                ViInt32 blankTime);
ViStatus _VI_FUNC rssmr_setLFSweepDwellTime (ViSession instrSession,
                ViReal64 time);
ViStatus _VI_FUNC rssmr_setLFSweepTime (ViSession instrSession, ViReal64 time);
ViStatus _VI_FUNC rssmr_configureLFMarker (ViSession instrSession,
                ViInt32 marker, ViBoolean state,
                ViReal64 frequency, ViInt32 polarity);
ViStatus _VI_FUNC rssmr_setLFMarkState (ViSession instrSession, ViInt32 marker,
                ViBoolean state);
ViStatus _VI_FUNC rssmr_setLFMarkFreq (ViSession instrSession, ViInt32 marker,
                ViReal64 frequency);
ViStatus _VI_FUNC rssmr_setLFMarkPolar (ViSession instrSession, ViInt32 marker,
                ViInt32 polarity);
ViStatus _VI_FUNC rssmr_configPulseOutput (ViSession instrSession,
                ViInt32 polarity, ViReal64 pulsePeriod,
                ViReal64 pulseWidth,
                ViReal64 pulseDelay);
ViStatus _VI_FUNC rssmr_configVideoOutput (ViSession instrSession,
                ViInt32 vGHzScale);
ViStatus _VI_FUNC rssmr_setPulseSource (ViSession instrSession, ViInt32 source);
ViStatus _VI_FUNC rssmr_setPulsePolarity (ViSession instrSession,
                ViInt32 polarity);
ViStatus _VI_FUNC rssmr_setBlankSignalPolarity (ViSession instrSession,
                                                ViInt32 polarity);
ViStatus _VI_FUNC rssmr_setPulsePeriod (ViSession instrSession,
                ViReal64 period);
ViStatus _VI_FUNC rssmr_setRfBlankingBehaviorSync (ViSession instrSession,
                                                   ViBoolean state);
ViStatus _VI_FUNC rssmr_setRfBlankingBehavior (ViSession instrSession,
                                               ViInt32 RFBlankingBehavior);
ViStatus _VI_FUNC rssmr_setVGHzOutputScale (ViSession instrSession,
                ViInt32 signalScale);
ViStatus _VI_FUNC rssmr_setPulseWidth (ViSession instrSession, ViReal64 width);
ViStatus _VI_FUNC rssmr_setPulseDelay (ViSession instrSession, ViReal64 delay);
ViStatus _VI_FUNC rssmr_setDoublePulseState (ViSession instrSession,
                ViBoolean state);
ViStatus _VI_FUNC rssmr_setDoublePulseDelay (ViSession instrSession,
                ViReal64 delay);
ViStatus _VI_FUNC rssmr_setIFInputState (ViSession instrSession,
                ViBoolean IFInputState);
ViStatus _VI_FUNC rssmr_configureRefOscilator (ViSession instrSession,
                ViBoolean refOscState,
                ViInt32 refSource,
                ViInt32 adjustValue);
ViStatus _VI_FUNC rssmr_setRFOscState (ViSession instrSession,
                ViBoolean refOscState);
ViStatus _VI_FUNC rssmr_setRefOscSource (ViSession instrSession,
                ViInt32 refSource);
ViStatus _VI_FUNC rssmr_setRefOscAdjVal (ViSession instrSession, ViInt32 value);
ViStatus _VI_FUNC rssmr_configureList (ViSession instrSession, ViInt32 listMode,
                ViString list_name, ViReal64 time,
                ViReal64 _VI_FAR frequencyPoints[],
                ViReal64 _VI_FAR powerPoints[],
                ViInt32 numberOfElements);
ViStatus _VI_FUNC rssmr_setListMode (ViSession instrSession, ViInt32 listMode);
ViStatus _VI_FUNC rssmr_selList (ViSession instrSession, ViString list_name);
ViStatus _VI_FUNC rssmr_deleteList (ViSession instrSession, ViString list_name);
ViStatus _VI_FUNC rssmr_deleteAllLists (ViSession instrSession);
ViStatus _VI_FUNC rssmr_getListOfLists (ViSession instrSession,
                ViChar _VI_FAR listOfLists[]);
ViStatus _VI_FUNC rssmr_setListDwellTime (ViSession instrSession,
                ViReal64 time);
ViStatus _VI_FUNC rssmr_getListDwellPoints (ViSession instrSession,
                ViPInt32 points);
ViStatus _VI_FUNC rssmr_getSpaceProperties (ViSession instrSession,
                ViPInt32 freeSpace,
                ViPInt32 occupiedSpace);
ViStatus _VI_FUNC rssmr_setFreqToList (ViSession instrSession,
                ViReal64 _VI_FAR frequency[], ViInt32 size);
ViStatus _VI_FUNC rssmr_getFreqPoints (ViSession instrSession, ViPInt32 points);
ViStatus _VI_FUNC rssmr_setPowerToList (ViSession instrSession,
                ViReal64 _VI_FAR power[], ViInt32 size);
ViStatus _VI_FUNC rssmr_getPowerPoints (ViSession instrSession,
                ViPInt32 points);
ViStatus _VI_FUNC rssmr_setListPowerMode (ViSession instrSession);
ViStatus _VI_FUNC rssmr_setListBlankingBehavior (ViSession instrumentHandle,
                                                 ViBoolean state);
ViStatus _VI_FUNC rssmr_setMarkerFreqSweepState (ViSession instrSession,
                ViInt32 markerNo,
                ViBoolean markerState);
ViStatus _VI_FUNC rssmr_setMarkerFreqSweepAmp (ViSession instrSession,
                ViInt32 markerNo,
                ViBoolean amplitude);
ViStatus _VI_FUNC rssmr_setMarkerFreqSweepFreq (ViSession instrSession,
                ViInt32 markerNo,
                ViReal64 frequency);
ViStatus _VI_FUNC rssmr_setMarkerLevelSweepState (ViSession instrSession,
                ViInt32 markerNo,
                ViBoolean state);
ViStatus _VI_FUNC rssmr_setMarkerLevelSweepPower (ViSession instrSession,
                ViInt32 markerNo, ViReal64 power);
ViStatus _VI_FUNC rssmr_setSweepTrigSource (ViSession instrSession,
                ViInt32 generator,
                ViInt32 triggerSource);
ViStatus _VI_FUNC rssmr_setListTrigSource (ViSession instrSession,
                ViInt32 triggerSource);
ViStatus _VI_FUNC rssmr_setPulseTrigSource (ViSession instrSession,
                ViInt32 triggerSource);
ViStatus _VI_FUNC rssmr_setPulseTrigSlope (ViSession instrSession,
                ViInt32 triggerSlope);
ViStatus _VI_FUNC rssmr_setPulseTrigLevel (ViSession instrSession,
                                           ViInt32 triggerLevel);
ViStatus _VI_FUNC rssmr_setPulseTrigPolarity (ViSession instrSession,
                                              ViInt32 triggerPolarity);
ViStatus _VI_FUNC rssmr_setSlopeTrig (ViSession instrSession,
                ViInt32 triggerSlope);
ViStatus _VI_FUNC rssmr_setLevCalState (ViSession instrSession,
                                        ViBoolean levelCalibration);
ViStatus _VI_FUNC rssmr_getRefOscCalVal (ViSession instrSession,
                                         ViPInt32 value);
ViStatus _VI_FUNC rssmr_storeRefOscCalVal (ViSession instrSession);
ViStatus _VI_FUNC rssmr_SendTrigger (ViSession instrSession, ViInt32 generator,
                ViInt32 systemToTrigger);
ViStatus _VI_FUNC rssmr_abortTrigger (ViSession instrSession,
                ViInt32 systemToAbort);
ViStatus _VI_FUNC rssmr_LFMarkOff (ViSession instrSession);
ViStatus _VI_FUNC rssmr_markersFreqSweepOff (ViSession instrSession);
ViStatus _VI_FUNC rssmr_markersLevelSweepOff (ViSession instrSession);
ViStatus _VI_FUNC rssmr_calibration (ViSession instrSession,
                                         ViInt32 toCalibrate, ViInt32 timeout,
                                         ViChar _VI_FAR calibrationResults[]);
ViStatus _VI_FUNC rssmr_utilSystemKeylock (ViSession instrSession,
                                           ViBoolean lockout);
ViStatus _VI_FUNC rssmr_utilSetDisplayUpdate (ViSession instrSession,
                                              ViBoolean displayUpdate);
ViStatus _VI_FUNC rssmr_utilRecallSetup (ViSession instrSession,
                ViInt32 registerNo);
ViStatus _VI_FUNC rssmr_utilSaveSetup (ViSession instrSession,
                ViInt32 registerNo);
ViStatus _VI_FUNC rssmr_utilGetFreeSett (ViSession instrSession,
                ViPInt32 value);
ViStatus _VI_FUNC rssmr_utilSetReg (ViSession instrSession,
                ViInt32 registerName, ViInt32 value);
ViStatus _VI_FUNC rssmr_utilGetReg (ViSession instrSession,
                ViInt32 registerName, ViPInt32 value);
ViStatus _VI_FUNC rssmr_utilSetSystemMode (ViSession instrSession,
                ViInt32 mode);
ViStatus _VI_FUNC rssmr_utilSetDisplayMode (ViSession instrSession,
                ViInt32 parameter, ViBoolean state);
ViStatus _VI_FUNC rssmr_utilSetGPIBAddr (ViSession instrSession,
                ViInt32 address);
ViStatus _VI_FUNC rssmr_utilConfigureRS232 (ViSession instrSession,
                ViInt32 baudRate, ViInt32 dataBits,
                ViInt32 stopBits,
                ViInt32 hardwareHandshake,
                ViInt32 softwareHandshake,
                ViInt32 parity);
ViStatus _VI_FUNC rssmr_utilTest (ViSession instrSession, ViInt32 toTest,
                ViChar _VI_FAR testResults[]);
ViStatus _VI_FUNC rssmr_FlushErrorQueue (ViSession instrSession);
ViStatus _VI_FUNC rssmr_errorCheckState (ViSession instrSession,
                ViBoolean stateChecking);
ViStatus _VI_FUNC rssmr_writeInstrData (ViSession instrSession,
                ViString writeBuffer);
ViStatus _VI_FUNC rssmr_readInstrData (ViSession instrSession,
                ViInt32 numberBytesToRead,
                ViChar _VI_FAR readBuffer[],
                ViPInt32 numBytesRead);
ViStatus _VI_FUNC rssmr_reset (ViSession instrSession);
ViStatus _VI_FUNC rssmr_self_test (ViSession instrSession,
                ViPInt32 selfTestResult,
                ViChar _VI_FAR selfTestMessage[]);
ViStatus _VI_FUNC rssmr_error_query (ViSession instrSession, ViPInt32 errorCode,
                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rssmr_error_message (ViSession instrSession,
                ViStatus statusCode,
                ViChar _VI_FAR message[]);
ViStatus _VI_FUNC rssmr_revision_query (ViSession instrSession,
                ViChar _VI_FAR instrumentDriverRevision[],
                ViChar _VI_FAR firmwareRevision[]);
ViStatus _VI_FUNC rssmr_close (ViSession instrSession);


#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

/*****************************************************************************/
/*=== END INCLUDE FILE ======================================================*/
/*****************************************************************************/

#endif
